@@ -994,3 +994,7 @@ class TestDate(unittest.TestCase):
             pd.DataFrame(expected_quarter.dt.date),
             pd.DataFrame(actual_values)
         ], ignore_indexes=False)
+
+
+if __name__ == '__main__':
+    unittest.main()
